@@ -31,6 +31,7 @@
 #include "doxywizard.h"
 #include "expert.h"
 #include "config.h"
+#include "version.h"
 
 const int messageTimeout = 5000; //!< status bar message timeout in millisec.
 
@@ -1190,6 +1191,16 @@ void MainWidget::saveConfigFile()
   if (!fn.isEmpty())
   {
     QFile f(fn);
+    if (f.exists() && QMessageBox::question(this,
+          "Overwrite file? -- Doxywizard",
+          "A file called "+fn+" already exists. Do you want to overwrite it?",
+          "&Yes","&no",
+          QString::null, 0, 1)
+       )
+    {
+      statusBar()->message("Save request aborted",messageTimeout);
+      return;
+    }
     if (f.open(IO_WriteOnly))
     {
       QTextStream t(&f);
@@ -1310,9 +1321,9 @@ void MainWidget::about()
 {
   QString msg;
   QTextStream t(&msg,IO_WriteOnly);
-  t << "<qt><center>A tool to configure and run doxygen "
-       "on your source files.</center><p><br>"
-       "<center>Written by<br> Dimitri van Heesch<br>&copy; 2000-2004</center><p>"
+  t << QString("<qt><center>A tool to configure and run doxygen version ")+versionString+
+       " on your source files.</center><p><br>"
+       "<center>Written by<br> Dimitri van Heesch<br>&copy; 2000-2005</center><p>"
        "</qt>";
   QMessageBox::about(this,"Doxygen GUI",msg);
 }
