@@ -1,9 +1,9 @@
 /******************************************************************************
  *
- * 
+ * $Id: def.cpp,v 1.2 2001/01/01 10:15:18 root Exp $
  *
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -28,7 +28,6 @@
 #include "defargs.h"
 #include "outputgen.h"
 #include "dot.h"
-#include "code.h"
 
 #include <qdir.h>
 #include <qfile.h>
