@@ -2,7 +2,7 @@
  *
  * $Id: index.cpp,v 1.30 1999/03/06 22:15:39 root Exp $
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -543,7 +543,7 @@ void Definition::writeSourceRefList(OutputList &ol,const char *scopeName,
            ) name+="()";
         //Definition *d = md->getOutputFileBase();
         //if (d==Doxygen::globalScope) d=md->getBodyDef();
-        if (md->getStartBodyLine()!=-1 && md->getBodyDef()) 
+        if (!(md->isLinkable() && !Config_getBool("REFERENCES_LINK_SOURCE")) && md->getStartBodyLine()!=-1 && md->getBodyDef()) 
         {
           //printf("md->getBodyDef()=%p global=%p\n",md->getBodyDef(),Doxygen::globalScope); 
           // for HTML write a real link
@@ -702,10 +702,19 @@ QCString Definition::qualifiedName()
   {
     m_qualifiedName = m_outerScope->qualifiedName()+"::"+m_localName;
   }
-  //printf("end Definition::qualifiedName()=%s\n",qualifiedName.data());
+  //printf("end Definition::qualifiedName()=%s\n",m_qualifiedName.data());
   return m_qualifiedName;
 };
 
+void Definition::setOuterScope(Definition *d) 
+{
+  if (m_outerScope!=d)
+  { 
+    m_qualifiedName.resize(0); // flush cached scope name
+    m_outerScope = d; 
+  }
+}
+
 QCString Definition::localName() const
 {
   return m_localName;
