@@ -1,9 +1,9 @@
 /*****************************************************************************
  *
- * 
+ * $Id: dot.cpp,v 1.20 2001/03/19 19:27:40 root Exp $
  *
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -24,7 +24,6 @@
 #include "util.h"
 #include "config.h"
 #include "language.h"
-#include "scanner.h"
 #include "defargs.h"
 #include "docparser.h"
 #include "debug.h"
@@ -75,9 +74,9 @@ static void writeGraphHeader(QTextStream &t)
   {
     t << "  bgcolor=\"transparent\";" << endl;
   }
-  t << "  edge [fontname=\"Helvetica\",fontsize=10,"
-       "labelfontname=\"Helvetica\",labelfontsize=10];\n";
-  t << "  node [fontname=\"Helvetica\",fontsize=10,shape=record];\n";
+  t << "  edge [fontname=\"FreeSans.ttf\",fontsize=10,"
+       "labelfontname=\"FreeSans.ttf\",labelfontsize=10];\n";
+  t << "  node [fontname=\"FreeSans.ttf\",fontsize=10,shape=record];\n";
 }
 
 static void writeGraphFooter(QTextStream &t)
@@ -200,7 +199,7 @@ static bool convertMapFile(QTextStream &t,const char *mapName,
   return TRUE;
 }
 
-static QArray<int> * s_newNumber = new QArray<int>();
+static QArray<int> s_newNumber;
 static int s_max_newNumber=0;
 
 inline int reNumberNode(int number, bool doReNumbering)
@@ -211,7 +210,7 @@ inline int reNumberNode(int number, bool doReNumbering)
   } 
   else 
   {
-    int s = s_newNumber->size();
+    int s = s_newNumber.size();
     if (number>=s) 
     {
       int ns=0;
@@ -220,17 +219,17 @@ inline int reNumberNode(int number, bool doReNumbering)
       {
         ns = number * 3 / 2 + 5;
       }
-      s_newNumber->resize(ns);
+      s_newNumber.resize(ns);
       for (int i=s;i<ns;i++) // clear new part of the array
       {
-        s_newNumber->at(i)=0;
+        s_newNumber.at(i)=0;
       }
     }
-    int i = s_newNumber->at(number);
+    int i = s_newNumber.at(number);
     if (i == 0) // not yet mapped
     {
       i = ++s_max_newNumber; // start from 1
-      s_newNumber->at(number) = i;
+      s_newNumber.at(number) = i;
     }
     return i;
   }
@@ -239,7 +238,7 @@ inline int reNumberNode(int number, bool doReNumbering)
 static void resetReNumbering() 
 {
   s_max_newNumber=0;
-  s_newNumber->resize(s_max_newNumber);
+  s_newNumber.resize(s_max_newNumber);
 }
 
 static bool readBoundingBoxDot(const char *fileName,int *width,int *height)
@@ -275,10 +274,10 @@ static bool readBoundingBoxEPS(const char *fileName,int *width,int *height)
   {
     int numBytes = f.readLine(buf,maxLineLen);
     buf[numBytes-1]='\0';
-    if (strncmp(buf,"%%BoundingBox: ",15)==0)
+    if (strncmp(buf,"%%PageBoundingBox: ",15)==0)
     {
       int x,y;
-      if (sscanf(buf,"%%%%BoundingBox: %d %d %d %d",&x,&y,width,height)!=4)
+      if (sscanf(buf,"%%%%PageBoundingBox: %d %d %d %d",&x,&y,width,height)!=4)
       {
         return FALSE;
       }
@@ -288,6 +287,7 @@ static bool readBoundingBoxEPS(const char *fileName,int *width,int *height)
   return FALSE;
 }
 
+#if 0
 /*! returns TRUE if class cd is a leaf (i.e. has no visible children)
  */
 static bool isLeaf(ClassDef *cd)
@@ -312,6 +312,7 @@ static bool isLeaf(ClassDef *cd)
   }
   return TRUE;
 }
+#endif
 
 // since dot silently reproduces the input file when it does not
 // support the PNG format, we need to check the result.
@@ -414,7 +415,7 @@ bool DotRunner::run()
       dotArgs+=' ';
       dotArgs+=*s;
     }
-    if (iSystem(Config_getString("DOT_PATH")+"dot",dotArgs)!=0)
+    if (iSystem(Config_getString("DOT_PATH")+"dot",dotArgs,FALSE)!=0)
     {
       goto error;
     }
@@ -424,7 +425,7 @@ bool DotRunner::run()
     for (li.toFirst();(s=li.current());++li)
     {
       QCString dotArgs="\""+m_file+"\" "+*s;
-      if (iSystem(Config_getString("DOT_PATH")+"dot",dotArgs)!=0)
+      if (iSystem(Config_getString("DOT_PATH")+"dot",dotArgs,FALSE)!=0)
       {
         goto error;
       }
@@ -560,6 +561,7 @@ static QCString convertLabel(const QCString &l)
 {
   QCString result;
   const char *p=l.data();
+  if (p==0) return result;
   char c;
   while ((c=*p++))
   {
@@ -665,7 +667,7 @@ void DotNode::writeBox(QTextStream &t,
   t << "\",height=0.2,width=0.4";
   if (m_isRoot)
   {
-    t << ",color=\"white\", fillcolor=\"black\", style=\"filled\" fontcolor=\"white\"";
+    t << ",color=\"black\", fillcolor=\"grey75\", style=\"filled\" fontcolor=\"black\"";
   }
   else 
   {
@@ -727,7 +729,7 @@ void DotNode::writeArrow(QTextStream &t,
       t << ",arrowhead=\"" << arrowStyle[ei->m_color] << "\"";
   }
 
-  if (format==BITMAP) t << ",fontname=\"Helvetica\"";
+  if (format==BITMAP) t << ",fontname=\"FreeSans.ttf\"";
   t << "];" << endl; 
 }
 
@@ -1152,7 +1154,7 @@ void DotGfxHierarchyTable::addHierarchy(DotNode *n,ClassDef *cd,bool hideSuper)
   for ( ; (bcd=bcli.current()) ; ++bcli )
   {
     ClassDef *bClass=bcd->classDef; 
-    //printf("  Trying super class=`%s' usedNodes=%d\n",bClass->name().data(),m_usedNodes->count());
+    //printf("  Trying sub class=`%s' usedNodes=%d\n",bClass->name().data(),m_usedNodes->count());
     if (bClass->isVisibleInHierarchy() && hasVisibleRoot(bClass->baseClasses()))
     {
       DotNode *bn;
@@ -1179,8 +1181,10 @@ void DotGfxHierarchyTable::addHierarchy(DotNode *n,ClassDef *cd,bool hideSuper)
       else 
       {
         QCString tmp_url="";
-        if (bClass->isLinkable()) 
+        if (bClass->isLinkable() && !bClass->isHidden())
+        {
           tmp_url=bClass->getReference()+"$"+bClass->getOutputFileBase();
+        }
         bn = new DotNode(m_curNodeNumber++,
              bClass->displayName(),
              tmp_url.data()
@@ -1219,8 +1223,10 @@ void DotGfxHierarchyTable::addClassList(ClassSDict *cl)
        ) // root node in the forest
     {
       QCString tmp_url="";
-      if (cd->isLinkable()) 
+      if (cd->isLinkable() && !cd->isHidden()) 
+      {
         tmp_url=cd->getReference()+"$"+cd->getOutputFileBase();
+      }
       //printf("Inserting root class %s\n",cd->name().data());
       DotNode *n = new DotNode(m_curNodeNumber++,
           cd->displayName(),
@@ -1354,7 +1360,7 @@ void DotClassGraph::addClass(ClassDef *cd,DotNode *n,int prot,
     QCString displayName=className;
     if (Config_getBool("HIDE_SCOPE_NAMES")) displayName=stripScope(displayName);
     QCString tmp_url;
-    if (cd->isLinkable()) 
+    if (cd->isLinkable() && !cd->isHidden()) 
     {
       tmp_url=cd->getReference()+"$"+cd->getOutputFileBase();
     }
@@ -1377,7 +1383,8 @@ void DotClassGraph::addClass(ClassDef *cd,DotNode *n,int prot,
       n->addParent(bn);
     }
     m_usedNodes->insert(className,bn);
-    //printf(" add new child node `%s' to %s\n",className.data(),n->m_label.data());
+    //printf(" add new child node `%s' to %s hidden=%d url=%s\n",
+    //    className.data(),n->m_label.data(),cd->isHidden(),tmp_url.data());
     
     // we use <=, i.s.o < to cause one more level than intended which is used to 
     // detect truncated nodes
@@ -1493,7 +1500,10 @@ DotClassGraph::DotClassGraph(ClassDef *cd,DotNode::GraphType t,int maxRecursionD
   m_maxDistance = 0;
   m_recDepth = maxRecursionDepth;
   QCString tmp_url="";
-  if (cd->isLinkable()) tmp_url=cd->getReference()+"$"+cd->getOutputFileBase();
+  if (cd->isLinkable() && !cd->isHidden()) 
+  {
+    tmp_url=cd->getReference()+"$"+cd->getOutputFileBase();
+  }
   QCString className = cd->displayName();
   //if (cd->templateArguments())
   //{
@@ -1843,7 +1853,7 @@ QCString DotClassGraph::writeGraph(QTextStream &out,
         QCString epstopdfArgs(maxCmdLine);
         epstopdfArgs.sprintf("\"%s.eps\" --outfile=\"%s.pdf\"",
             baseName.data(),baseName.data());
-        if (iSystem("epstopdf",epstopdfArgs,TRUE)!=0)
+        if (iSystem("epstopdf",epstopdfArgs)!=0)
         {
           err("Error: Problems running epstopdf. Check your TeX installation!\n");
           QDir::setCurrent(oldDir);
@@ -1949,7 +1959,7 @@ void DotInclDepGraph::buildGraph(DotNode *n,FileDef *fd,int distance)
     if (bfd)
     {
       in  = bfd->absFilePath();  
-      doc = bfd->isLinkable();
+      doc = bfd->isLinkable() && !bfd->isHidden();
       src = bfd->generateSourceFile();
     }
     if (doc || src || !Config_getBool("HIDE_UNDOC_RELATIONS"))
@@ -1958,7 +1968,7 @@ void DotInclDepGraph::buildGraph(DotNode *n,FileDef *fd,int distance)
       if (bfd) url=bfd->getOutputFileBase().copy();
       if (!doc && src)
       {
-        url+="-source";
+        url=bfd->getSourceFileBase();
       }
       DotNode *bn  = m_usedNodes->find(in);
       if (bn) // file is already a node in the graph
@@ -2101,7 +2111,7 @@ QCString DotInclDepGraph::writeGraph(QTextStream &out,
         QCString epstopdfArgs(maxCmdLine);
         epstopdfArgs.sprintf("\"%s.eps\" --outfile=\"%s.pdf\"",
             baseName.data(),baseName.data());
-        if (iSystem("epstopdf",epstopdfArgs,TRUE)!=0)
+        if (iSystem("epstopdf",epstopdfArgs)!=0)
         {
           err("Error: Problems running epstopdf. Check your TeX installation!\n");
           QDir::setCurrent(oldDir);
@@ -2174,10 +2184,11 @@ void DotInclDepGraph::writeXML(QTextStream &t)
 
 int DotCallGraph::m_curNodeNumber = 0;
 
-DotCallGraph::DotCallGraph(MemberDef *md,int maxRecursionDepth)
+DotCallGraph::DotCallGraph(MemberDef *md,int maxRecursionDepth,bool inverse)
 {
   m_maxDistance = 0;
   m_recDepth = maxRecursionDepth;
+  m_inverse = inverse;
   m_diskName = md->getOutputFileBase()+"_"+md->anchor();
   m_scope    = md->getOuterScope();
   QCString uniqueId;
@@ -2223,7 +2234,7 @@ QCString DotCallGraph::writeGraph(QTextStream &out, GraphOutputFormat format,
   QDir::setCurrent(d.absPath());
   QDir thisDir;
 
-  QCString baseName=m_diskName+"_cgraph";
+  QCString baseName = m_diskName + (m_inverse ? "_icgraph" : "_cgraph");
   QCString mapName=baseName;
   QCString imgExt = Config_getEnum("DOT_IMAGE_FORMAT");
 
@@ -2247,7 +2258,7 @@ QCString DotCallGraph::writeGraph(QTextStream &out, GraphOutputFormat format,
                         format,                           // format
                         TRUE,                             // lrRank
                         FALSE,                            // renderParents
-                        FALSE                             // backArrows
+                        m_inverse                         // backArrows
                        );
     if (format==BITMAP)
     {
@@ -2279,7 +2290,7 @@ QCString DotCallGraph::writeGraph(QTextStream &out, GraphOutputFormat format,
         QCString epstopdfArgs(maxCmdLine);
         epstopdfArgs.sprintf("\"%s.eps\" --outfile=\"%s.pdf\"",
             baseName.data(),baseName.data());
-        if (iSystem("epstopdf",epstopdfArgs,TRUE)!=0)
+        if (iSystem("epstopdf",epstopdfArgs)!=0)
         {
           err("Error: Problems running epstopdf. Check your TeX installation!\n");
           QDir::setCurrent(oldDir);
@@ -2335,7 +2346,7 @@ QCString DotCallGraph::writeGraph(QTextStream &out, GraphOutputFormat format,
 
 void DotCallGraph::buildGraph(DotNode *n,MemberDef *md,int distance)
 {
-  MemberSDict *refs = md->getReferencesMembers();
+  MemberSDict *refs = m_inverse ? md->getReferencedByMembers() : md->getReferencesMembers();
   if (refs)
   {
     MemberSDict::Iterator mri(*refs);
@@ -2463,7 +2474,7 @@ QCString DotDirDeps::writeGraph(QTextStream &out,
         QCString epstopdfArgs(maxCmdLine);
         epstopdfArgs.sprintf("\"%s.eps\" --outfile=\"%s.pdf\"",
             baseName.data(),baseName.data());
-        if (iSystem("epstopdf",epstopdfArgs,TRUE)!=0)
+        if (iSystem("epstopdf",epstopdfArgs)!=0)
         {
           err("Error: Problems running epstopdf. Check your TeX installation!\n");
           QDir::setCurrent(oldDir);
@@ -2542,23 +2553,23 @@ void generateGraphLegend(const char *path)
   }
   QTextStream dotText(&dotFile); 
   writeGraphHeader(dotText);
-  dotText << "  Node9 [shape=\"box\",label=\"Inherited\",fontsize=10,height=0.2,width=0.4,fontname=\"Helvetica\",color=\"black\",style=\"filled\" fontcolor=\"white\"];\n";
-  dotText << "  Node10 -> Node9 [dir=back,color=\"midnightblue\",fontsize=10,style=\"solid\",fontname=\"Helvetica\"];\n";
-  dotText << "  Node10 [shape=\"box\",label=\"PublicBase\",fontsize=10,height=0.2,width=0.4,fontname=\"Helvetica\",color=\"black\",URL=\"$classPublicBase" << Doxygen::htmlFileExtension << "\"];\n";
-  dotText << "  Node11 -> Node10 [dir=back,color=\"midnightblue\",fontsize=10,style=\"solid\",fontname=\"Helvetica\"];\n";
-  dotText << "  Node11 [shape=\"box\",label=\"Truncated\",fontsize=10,height=0.2,width=0.4,fontname=\"Helvetica\",color=\"red\",URL=\"$classTruncated" << Doxygen::htmlFileExtension << "\"];\n";
-  dotText << "  Node13 -> Node9 [dir=back,color=\"darkgreen\",fontsize=10,style=\"solid\",fontname=\"Helvetica\"];\n";
-  dotText << "  Node13 [shape=\"box\",label=\"ProtectedBase\",fontsize=10,height=0.2,width=0.4,fontname=\"Helvetica\",color=\"black\",URL=\"$classProtectedBase" << Doxygen::htmlFileExtension << "\"];\n";
-  dotText << "  Node14 -> Node9 [dir=back,color=\"firebrick4\",fontsize=10,style=\"solid\",fontname=\"Helvetica\"];\n";
-  dotText << "  Node14 [shape=\"box\",label=\"PrivateBase\",fontsize=10,height=0.2,width=0.4,fontname=\"Helvetica\",color=\"black\",URL=\"$classPrivateBase" << Doxygen::htmlFileExtension << "\"];\n";
-  dotText << "  Node15 -> Node9 [dir=back,color=\"midnightblue\",fontsize=10,style=\"solid\",fontname=\"Helvetica\"];\n";
-  dotText << "  Node15 [shape=\"box\",label=\"Undocumented\",fontsize=10,height=0.2,width=0.4,fontname=\"Helvetica\",color=\"grey75\"];\n";
-  dotText << "  Node16 -> Node9 [dir=back,color=\"midnightblue\",fontsize=10,style=\"solid\",fontname=\"Helvetica\"];\n";
-  dotText << "  Node16 [shape=\"box\",label=\"Templ< int >\",fontsize=10,height=0.2,width=0.4,fontname=\"Helvetica\",color=\"black\",URL=\"$classTempl" << Doxygen::htmlFileExtension << "\"];\n";
-  dotText << "  Node17 -> Node16 [dir=back,color=\"orange\",fontsize=10,style=\"dashed\",label=\"< int >\",fontname=\"Helvetica\"];\n";
-  dotText << "  Node17 [shape=\"box\",label=\"Templ< T >\",fontsize=10,height=0.2,width=0.4,fontname=\"Helvetica\",color=\"black\",URL=\"$classTempl" << Doxygen::htmlFileExtension << "\"];\n";
-  dotText << "  Node18 -> Node9 [dir=back,color=\"darkorchid3\",fontsize=10,style=\"dashed\",label=\"m_usedClass\",fontname=\"Helvetica\"];\n";
-  dotText << "  Node18 [shape=\"box\",label=\"Used\",fontsize=10,height=0.2,width=0.4,fontname=\"Helvetica\",color=\"black\",URL=\"$classUsed" << Doxygen::htmlFileExtension << "\"];\n";
+  dotText << "  Node9 [shape=\"box\",label=\"Inherited\",fontsize=10,height=0.2,width=0.4,fontname=\"FreeSans.ttf\",fillcolor=\"grey75\",style=\"filled\" fontcolor=\"black\"];\n";
+  dotText << "  Node10 -> Node9 [dir=back,color=\"midnightblue\",fontsize=10,style=\"solid\",fontname=\"FreeSans.ttf\"];\n";
+  dotText << "  Node10 [shape=\"box\",label=\"PublicBase\",fontsize=10,height=0.2,width=0.4,fontname=\"FreeSans.ttf\",color=\"black\",URL=\"$classPublicBase" << Doxygen::htmlFileExtension << "\"];\n";
+  dotText << "  Node11 -> Node10 [dir=back,color=\"midnightblue\",fontsize=10,style=\"solid\",fontname=\"FreeSans.ttf\"];\n";
+  dotText << "  Node11 [shape=\"box\",label=\"Truncated\",fontsize=10,height=0.2,width=0.4,fontname=\"FreeSans.ttf\",color=\"red\",URL=\"$classTruncated" << Doxygen::htmlFileExtension << "\"];\n";
+  dotText << "  Node13 -> Node9 [dir=back,color=\"darkgreen\",fontsize=10,style=\"solid\",fontname=\"FreeSans.ttf\"];\n";
+  dotText << "  Node13 [shape=\"box\",label=\"ProtectedBase\",fontsize=10,height=0.2,width=0.4,fontname=\"FreeSans.ttf\",color=\"black\",URL=\"$classProtectedBase" << Doxygen::htmlFileExtension << "\"];\n";
+  dotText << "  Node14 -> Node9 [dir=back,color=\"firebrick4\",fontsize=10,style=\"solid\",fontname=\"FreeSans.ttf\"];\n";
+  dotText << "  Node14 [shape=\"box\",label=\"PrivateBase\",fontsize=10,height=0.2,width=0.4,fontname=\"FreeSans.ttf\",color=\"black\",URL=\"$classPrivateBase" << Doxygen::htmlFileExtension << "\"];\n";
+  dotText << "  Node15 -> Node9 [dir=back,color=\"midnightblue\",fontsize=10,style=\"solid\",fontname=\"FreeSans.ttf\"];\n";
+  dotText << "  Node15 [shape=\"box\",label=\"Undocumented\",fontsize=10,height=0.2,width=0.4,fontname=\"FreeSans.ttf\",color=\"grey75\"];\n";
+  dotText << "  Node16 -> Node9 [dir=back,color=\"midnightblue\",fontsize=10,style=\"solid\",fontname=\"FreeSans.ttf\"];\n";
+  dotText << "  Node16 [shape=\"box\",label=\"Templ< int >\",fontsize=10,height=0.2,width=0.4,fontname=\"FreeSans.ttf\",color=\"black\",URL=\"$classTempl" << Doxygen::htmlFileExtension << "\"];\n";
+  dotText << "  Node17 -> Node16 [dir=back,color=\"orange\",fontsize=10,style=\"dashed\",label=\"< int >\",fontname=\"FreeSans.ttf\"];\n";
+  dotText << "  Node17 [shape=\"box\",label=\"Templ< T >\",fontsize=10,height=0.2,width=0.4,fontname=\"FreeSans.ttf\",color=\"black\",URL=\"$classTempl" << Doxygen::htmlFileExtension << "\"];\n";
+  dotText << "  Node18 -> Node9 [dir=back,color=\"darkorchid3\",fontsize=10,style=\"dashed\",label=\"m_usedClass\",fontname=\"FreeSans.ttf\"];\n";
+  dotText << "  Node18 [shape=\"box\",label=\"Used\",fontsize=10,height=0.2,width=0.4,fontname=\"FreeSans.ttf\",color=\"black\",URL=\"$classUsed" << Doxygen::htmlFileExtension << "\"];\n";
   writeGraphFooter(dotText);
   dotFile.close();
 
@@ -2634,7 +2645,7 @@ void writeDotGraphFromFile(const char *inFile,const char *outDir,
     QCString epstopdfArgs(maxCmdLine);
     epstopdfArgs.sprintf("\"%s.eps\" --outfile=\"%s.pdf\"",
                          outFile,outFile);
-    if (iSystem("epstopdf",epstopdfArgs,TRUE)!=0)
+    if (iSystem("epstopdf",epstopdfArgs)!=0)
     {
       err("Error: Problems running epstopdf. Check your TeX installation!\n");
     }
@@ -2976,7 +2987,7 @@ QCString DotGroupCollaboration::writeGraph( QTextStream &t, GraphOutputFormat fo
       QCString epstopdfArgs(maxCmdLine);
       epstopdfArgs.sprintf("\"%s.eps\" --outfile=\"%s.pdf\"",
           baseName.data(),baseName.data());
-      if (iSystem("epstopdf",epstopdfArgs,TRUE)!=0)
+      if (iSystem("epstopdf",epstopdfArgs)!=0)
       {
         err("Error: Problems running epstopdf. Check your TeX installation!\n");
         QDir::setCurrent(oldDir);
@@ -3081,8 +3092,8 @@ void DotGroupCollaboration::writeGraphHeader(QTextStream &t)
   {
     t << "  bgcolor=\"transparent\";" << endl;
   }
-  t << "  edge [fontname=\"Helvetica\",fontsize=8,"
-    "labelfontname=\"Helvetica\",labelfontsize=8];\n";
-  t << "  node [fontname=\"Helvetica\",fontsize=10,shape=record];\n";
+  t << "  edge [fontname=\"FreeSans.ttf\",fontsize=8,"
+    "labelfontname=\"FreeSans.ttf\",labelfontsize=8];\n";
+  t << "  node [fontname=\"FreeSans.ttf\",fontsize=10,shape=record];\n";
   t << "rankdir=LR;\n";
 }
