@@ -2,7 +2,7 @@
  *
  * $Id: htmlgen.cpp,v 1.56 2001/03/19 19:27:40 root Exp $
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -1235,37 +1235,60 @@ void HtmlGenerator::endIndexValue(const char *,bool)
   t << "</td></tr>" << endl;
 }
 
+void HtmlGenerator::startMemberDocList()
+{
+  DBG_HTML(t << "<!-- startMemberDocList -->" << endl;)
+  //t << "<table class=\"memlist\">" << endl;
+  //t << "  <tr>" << endl;
+  //t << "    <td>" << endl;
+}
+
+void HtmlGenerator::endMemberDocList()
+{
+  DBG_HTML(t << "<!-- endMemberDocList -->" << endl;)
+  //t << "    </td>" << endl;
+  //t << "  </tr>" << endl;
+  //t << "</table>" << endl;
+}
+
 void HtmlGenerator::startMemberDoc(const char *,const char *,const char *,const char *) 
 { 
   DBG_HTML(t << "<!-- startMemberDoc -->" << endl;)
-  t << "<p>" << endl;
-  t << "<table class=\"mdTable\" cellpadding=\"2\" cellspacing=\"0\">" << endl;
-  t << "  <tr>" << endl;
-  t << "    <td class=\"mdRow\">" << endl; 
-  t << "      <table cellpadding=\"0\" cellspacing=\"0\" border=\"0\">" << endl;
+  //t << "<p>" << endl;
+ 
+  t << "\n<div class=\"memitem\">" << endl;
+  //t << "<table>" << endl;
+  //t << "  <tr>" << endl;
+  //t << "    <td>" << endl;
+  //t << "      <table class=\"memproto\">" << endl;
+  t << "<div class=\"memproto\">" << endl;
+  
 }
 
 void HtmlGenerator::startMemberDocPrefixItem()
 {
   DBG_HTML(t << "<!-- startMemberDocPrefixItem -->" << endl;)
-  t << "        <tr>" << endl;
-  t << "          <td class=\"mdPrefix\" colspan=\"4\">" << endl; 
+  //t << "        <tr>" << endl;
+  //t << "          <td class=\"memtemplate\" colspan=\"5\">";
+  t << "<div class=\"memtemplate\">" << endl;
 }
 
 void HtmlGenerator::endMemberDocPrefixItem()
 {
   DBG_HTML(t << "<!-- endMemberDocPrefixItem -->" << endl;)
-  t << "</td>" << endl;
-  t << "        </tr>" << endl;
+  //t << "</td>" << endl;
+  //t << "        </tr>" << endl;
+  t << "</div>" << endl;
 }
 
-void HtmlGenerator::startMemberDocName(bool align)
+void HtmlGenerator::startMemberDocName(bool /*align*/)
 {
   DBG_HTML(t << "<!-- startMemberDocName -->" << endl;)
+
+  t << "      <table class=\"memname\">" << endl;
+    
   t << "        <tr>" << endl;
-  t << "          <td class=\"md\" nowrap valign=\"top\"";
-  if (align) t << " align=\"right\"";
-  t << ">";
+  t << "          <td class=\"memname\">";
 }
 
 void HtmlGenerator::endMemberDocName()
@@ -1277,11 +1300,8 @@ void HtmlGenerator::endMemberDocName()
 void HtmlGenerator::startParameterList(bool openBracket)
 {
   DBG_HTML(t << "<!-- startParameterList -->" << endl;)
-  t << "          <td class=\"md\" valign=\"top\">";
-  if (openBracket)
-  {
-    t << "(&nbsp;";
-  }
+  t << "          <td>";
+  if (openBracket) t << "(";
   t << "</td>" << endl;
 }
 
@@ -1290,17 +1310,17 @@ void HtmlGenerator::startParameterType(bool first,const char *key)
   if (first)
   {
     DBG_HTML(t << "<!-- startFirstParameterType -->" << endl;)
-    t << "          <td class=\"md\" nowrap valign=\"top\">";
+    t << "          <td class=\"paramtype\">";
   }
   else
   {
     DBG_HTML(t << "<!-- startParameterType -->" << endl;)
     t << "        <tr>" << endl;
-    t << "          <td class=\"md\" nowrap align=\"right\">";
+    t << "          <td class=\"paramkey\">";
     if (key) t << key;
     t << "</td>" << endl;
-    t << "          <td class=\"md\"></td>" << endl;
-    t << "          <td class=\"md\" nowrap>";
+    t << "          <td></td>" << endl;
+    t << "          <td class=\"paramtype\">";
   }
 }
 
@@ -1310,15 +1330,10 @@ void HtmlGenerator::endParameterType()
   t << "&nbsp;</td>" << endl;
 }
 
-void HtmlGenerator::startParameterName(bool oneArgOnly)
+void HtmlGenerator::startParameterName(bool /*oneArgOnly*/)
 {
   DBG_HTML(t << "<!-- startParameterName -->" << endl;)
-  t << "          <td class=\"mdname";
-  if (oneArgOnly) 
-  {
-    t << "1\" valign=\"top";
-  }
-  t << "\" nowrap>"; //&nbsp;";
+  t << "          <td class=\"paramname\">";
 }
 
 void HtmlGenerator::endParameterName(bool last,bool emptyList,bool closeBracket)
@@ -1329,21 +1344,21 @@ void HtmlGenerator::endParameterName(bool last,bool emptyList,bool closeBracket)
     if (emptyList)
     {
       t << "          </td>" << endl;
-      t << "          <td class=\"md\" valign=\"top\">";
+      t << "          <td>";
       if (closeBracket) t << "&nbsp;)";
       t << "&nbsp;</td>" << endl;
-      t << "          <td class=\"md\" nowrap>";
+      t << "          <td width=\"100%\">";
     }
     else
     {
-      t << "</td>" << endl;
+      t << "</td><td>&nbsp;</td>" << endl;
       t << "        </tr>" << endl;
       t << "        <tr>" << endl;
-      t << "          <td class=\"md\"></td>" << endl;
-      t << "          <td class=\"md\">";
+      t << "          <td></td>" << endl;
+      t << "          <td>";
       if (closeBracket) t << ")";
-      t << "&nbsp;</td>" << endl;
-      t << "          <td class=\"md\" colspan=\"2\">";
+      t << "</td>" << endl;
+      t << "          <td></td><td></td><td width=\"100%\">";
     }
   }
   else
@@ -1368,9 +1383,10 @@ void HtmlGenerator::endMemberDoc(bool hasArgs)
     t << "        </tr>" << endl;
   }
   t << "      </table>" << endl;
-  t << "    </td>" << endl;
-  t << "  </tr>" << endl;
-  t << "</table>" << endl; 
+  //t << "    </td>" << endl;
+  //t << "  </tr>" << endl;
+  //t << "</table>" << endl;
+  t << "</div>" << endl;
 }
 
 void HtmlGenerator::startDotGraph()
@@ -1455,27 +1471,15 @@ void HtmlGenerator::endMemberGroup(bool)
 
 void HtmlGenerator::startIndent()        
 { 
-  // I really wanted to use CSS here to provide an indented section, but
-  // alas, Netscape is buggy enough to sometimes "forget" to end the
-  // indent cause a staircase effect where the indent continuously increases.
-  // It's back to abusing tables :-(
-  
-  //t << "<div class=\"in\">" << endl; 
+  DBG_HTML(t << "<!-- startIndent -->" << endl;)
 
-  t << "<table cellspacing=\"5\" cellpadding=\"0\" border=\"0\">\n"
-       "  <tr>\n"
-       "    <td>\n"
-       "      &nbsp;\n"
-       "    </td>\n"
-       "    <td>\n";
+  t << "<div class=\"memdoc\">\n";
 }
 
 void HtmlGenerator::endIndent()          
 { 
-  t << "    </td>\n"
-       "  </tr>\n"
-       "</table>\n";
-  //t << "</div>" << endl; 
+  DBG_HTML(t << "<!-- endIndent -->" << endl;)
+  t << endl << "</div>" << endl << "</div><p>" << endl; 
 }
 
 void HtmlGenerator::addIndexItem(const char *,const char *)
@@ -1813,7 +1817,14 @@ static void writeDefaultQuickLinks(QTextStream &t,bool compact,
     {
       startQuickIndexItem(t,"namespacemembers"+Doxygen::htmlFileExtension,
           hli==HLI_NamespaceMembers,compact,first,relPath);
-      t << fixSpaces(theTranslator->trNamespaceMembers());
+      if (Config_getBool("OPTIMIZE_OUTPUT_JAVA"))
+      {
+        t << fixSpaces(theTranslator->trPackageMembers());
+      }
+      else
+      {
+        t << fixSpaces(theTranslator->trNamespaceMembers());
+      }
       endQuickIndexItem(t);
     }
     endQuickIndexList(t,compact);
