@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -34,6 +34,9 @@
 #ifdef LANG_FR
 #include "translator_fr.h"
 #endif
+#ifdef LANG_ID
+#include "translator_id.h"
+#endif
 #ifdef LANG_IT
 #include "translator_it.h"
 #endif
@@ -165,6 +168,12 @@ bool setTranslator(const char *langName)
     theTranslator=new TranslatorFrench;
   }
 #endif
+#ifdef LANG_ID  
+  else if (L_EQUAL("indonesian"))
+  {
+    theTranslator=new TranslatorIndonesian;
+  }
+#endif
 #ifdef LANG_IT  
   else if (L_EQUAL("italian"))
   {
@@ -323,6 +332,12 @@ bool setTranslator(const char *langName)
     theTranslator=new TranslatorLithuanian;
   }
 #endif
+#ifdef LANG_ZA
+  else if (L_EQUAL("afrikaans"))
+  {
+    theTranslator=new TranslatorAfrikaans;
+  }
+#endif
 #endif // ENGLISH_ONLY
   else // use the default language (i.e. english)
   {
