@@ -1,8 +1,8 @@
 /******************************************************************************
  *
- * 
+ * $Id: outputgen.h,v 1.48 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -39,9 +39,10 @@ class GroupDef;
 
 /*! \brief Output interface for code parser. 
  */
-class BaseCodeDocInterface
+class CodeOutputInterface
 {
   public:
+    virtual ~CodeOutputInterface() {}
     /*! Writes an ASCII string to the output. This function should keep 
      *  spaces visible, should break lines at a newline and should convert 
      *  tabs to the right number of spaces.
@@ -78,9 +79,10 @@ class BaseCodeDocInterface
  *  or a list of formats (see OutputList). This interface
  *  contains functions that generate fragments of the output.
  */
-class BaseOutputDocInterface : public BaseCodeDocInterface
+class BaseOutputDocInterface : public CodeOutputInterface
 {
   public:
+    virtual ~BaseOutputDocInterface() {}
     enum ParamListTypes { Param, RetVal, Exception };
     enum SectionTypes { /*See, Return, Author, Version, 
                         Since, Date, Bug, Note,
@@ -272,7 +274,7 @@ class OutputGenerator : public BaseOutputDocInterface
     void pushGeneratorState();
     void popGeneratorState();
 
-    virtual void printDoc(DocNode *) = 0;
+    virtual void printDoc(DocNode *,const char *langExt) = 0;
 
     ///////////////////////////////////////////////////////////////
     // structural output interface
@@ -304,8 +306,10 @@ class OutputGenerator : public BaseOutputDocInterface
     virtual void endMemberHeader() = 0;
     virtual void startMemberSubtitle() = 0;
     virtual void endMemberSubtitle() = 0;
-    virtual void startMemberList()  = 0;
-    virtual void endMemberList()    = 0;
+    virtual void startMemberDocList() = 0;
+    virtual void endMemberDocList() = 0;
+    virtual void startMemberList() = 0;
+    virtual void endMemberList() = 0;
     virtual void startAnonTypeScope(int) = 0;
     virtual void endAnonTypeScope(int) = 0;
     virtual void startMemberItem(int) = 0;
