@@ -1,8 +1,8 @@
 /******************************************************************************
  *
- * 
+ * $Id: outputlist.h,v 1.47 2001/03/19 19:27:41 root Exp $
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -162,6 +162,10 @@ class OutputList : public OutputDocInterface
     { forall(&OutputGenerator::startMemberSubtitle); }
     void endMemberSubtitle()
     { forall(&OutputGenerator::endMemberSubtitle); }
+    void startMemberDocList() 
+    { forall(&OutputGenerator::startMemberDocList); }
+    void endMemberDocList() 
+    { forall(&OutputGenerator::endMemberDocList); }
     void startMemberList() 
     { forall(&OutputGenerator::startMemberList); }
     void endMemberList() 
