@@ -3,7 +3,7 @@
  *
  *
  *
- * Copyright (C) 1997-2004 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby
@@ -72,7 +72,7 @@
 #ifndef TRANSLATOR_DK_H
 #define TRANSLATOR_DK_H
 
-class TranslatorDanish : public Translator
+class TranslatorDanish : public TranslatorAdapter_1_3_9
 {
   public:
 
@@ -1445,6 +1445,19 @@ class TranslatorDanish : public Translator
       return "Fundne ord:"; //translation?
     }
 
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.8
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used in HTML as the title of page with source code for
+     *  file filename
+     */
+    virtual QCString trSourceFile(QCString& filename)
+    {
+      return "Kildefilen " + filename;
+    }
+
+
 /*---------- For internal use: ----------------------------------------*/
   protected:
 	/*! For easy flexible-noun implementation.
