@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2002 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -20,19 +20,17 @@
  * Some notes:
  * - It's posible that some sentences haven't got meaning because  
  * some words haven't got translate in spanish.
+ * Updated from 1.3.8 to 1.4.6 by Guillermo Ballester Valor (May-05-2006)
  */
 
 #ifndef TRANSLATOR_ES_H
 #define TRANSLATOR_ES_H
 
-class TranslatorSpanish : public TranslatorAdapter_1_2_7
+class TranslatorSpanish : public TranslatorAdapter_1_4_6
 {
   public:
     virtual QCString idLanguage()
     { return "spanish"; }
-    /*! returns the name of the package that is included by LaTeX */
-    virtual QCString latexBabelPackage() 
-    { return ""; }
 
     /*! Used to get the LaTeX command(s) for the language support. 
      *  This method should return string with commands that switch
@@ -50,7 +48,7 @@ class TranslatorSpanish : public TranslatorAdapter_1_2_7
      */
     virtual QCString latexLanguageSupportCommand()
     {
-      return "";
+      return "\\usepackage[spanish]{babel}";
     }
 
     /*! return the language charset. This will be used for the HTML output */
@@ -129,16 +127,10 @@ class TranslatorSpanish : public TranslatorAdapter_1_2_7
     virtual QCString trDefinedIn()
     { return "definido en"; }
 
-    /*! put as in introduction in the verbatim header file of a class.
-     *  parameter f is the name of the include file.
-     */
-    virtual QCString trVerbatimText(const char *f)
-    { return (QCString)"Este es el texto al pie de la letra del archivo "+f+" adjunto."; }
-    
     // quick reference sections
 
     /*! This is put above each page as a link to the list of all groups of 
-     *  compounds or files (see the \group command).
+     *  compounds or files (see the \\group command).
      */
     virtual QCString trModules()
     { return "Mdulos"; }
@@ -206,7 +198,7 @@ class TranslatorSpanish : public TranslatorAdapter_1_2_7
       QCString result="Lista de";
       if (!extractAll) result+=" toda la documentacin de";
       result+=" los miembros de la clase con enlaces a ";
-      if (extractAll) 
+      if (!extractAll) 
         result+=" la documentacin de cada clase:";
       else 
         result+=" la clase de la que forman parte:";
@@ -355,9 +347,14 @@ class TranslatorSpanish : public TranslatorAdapter_1_2_7
     virtual QCString trEnumerationValues()
     { return "Valores de la enumeracin"; }
     
-    /*! This is used in man pages as the author section. */
-    virtual QCString trAuthor()
-    { return "Autor"; }
+    /*! This text is generated when the \\author command is used and
+     *  for the author section in man pages. */
+    virtual QCString trAuthor(bool first_capital, bool singular)
+    {                                                                         
+      QCString result((first_capital ? "Autor" : "autor"));
+      if (!singular)  result+="s";
+      return result; 
+    }
 
     /*! This is used in the documentation of a file before the list of
      *  documentation blocks for defines
@@ -407,12 +404,6 @@ class TranslatorSpanish : public TranslatorAdapter_1_2_7
     virtual QCString trCompounds()
     { return "Clases"; }
 
-    /*! This is used in the documentation of a group before the list of 
-     *  links to documented files
-     */
-    virtual QCString trFiles()
-    { return "Archivos"; }
-
     /*! This is used in the standard footer of each page and indicates when 
      *  the page was generated 
      */
@@ -460,10 +451,6 @@ class TranslatorSpanish : public TranslatorAdapter_1_2_7
     virtual QCString trDate()
     { return "Fecha"; }
 
-    /*! this text is generated when the \\author command is used. */
-    virtual QCString trAuthors()
-    { return "Autor(es)"; }
-
     /*! this text is generated when the \return command is used. */
     virtual QCString trReturns()
     { return "Devuelve"; }
@@ -532,6 +519,8 @@ class TranslatorSpanish : public TranslatorAdapter_1_2_7
         case ClassDef::Struct:     result+="la Estructura "; break;
         case ClassDef::Union:      result+="la Unin "; break;
         case ClassDef::Interface:  result+="la Interfaz "; break;
+        case ClassDef::Protocol:   result+="Protocol "; break; // translate me!
+        case ClassDef::Category:   result+="Category "; break; // translate me!
         case ClassDef::Exception:  result+="la Excepcin "; break;
       }
       result+=(QCString)clName;
@@ -689,6 +678,8 @@ class TranslatorSpanish : public TranslatorAdapter_1_2_7
         case ClassDef::Struct:     result+="estructura"; break;
         case ClassDef::Union:      result+="unin"; break;
         case ClassDef::Interface:  result+="interfaz"; break;
+        case ClassDef::Protocol:   result+="protocol"; break; // translate me!
+        case ClassDef::Category:   result+="category"; break; // translate me!
         case ClassDef::Exception:  result+="excepcin"; break;
       }
       result+=" fu generada a partir ";
@@ -1221,7 +1212,241 @@ class TranslatorSpanish : public TranslatorAdapter_1_2_7
       if (!singular)  result+="es";
       return result; 
     }
-   
+
+    /*! This text is put before the list of members referenced by a member
+     */
+    virtual QCString trReferences()
+    {
+      return "Hace referencia a";
+    }
+
+    /*! used in member documentation blocks to produce a list of 
+     *  members that are implemented by this one.
+     */
+    virtual QCString trImplementedFromList(int numEntries)
+    {
+      return "Implementa "+trWriteList(numEntries)+".";
+    }
+
+    /*! used in member documentation blocks to produce a list of
+     *  all members that implement this abstract member.
+     */
+    virtual QCString trImplementedInList(int numEntries)
+    {
+      return "Implementado en "+trWriteList(numEntries)+".";
+    }
+
+    /*! used in RTF documentation as a heading for the Table
+     *  of Contents.
+     */
+    virtual QCString trRTFTableOfContents()
+    {
+      return "Tabla de Contenidos";
+    }
+
+    /*! Used as the header of the list of item that have been 
+     *  flagged deprecated 
+     */
+    virtual QCString trDeprecatedList()
+    {
+      return "Lista de Desaprobados";
+    }
+
+    /*! Used as a header for declaration section of the events found in 
+     * a C# program
+     */
+    virtual QCString trEvents()
+    {
+      return "Eventos";
+    }
+    
+    /*! Header used for the documentation section of a class' events. */
+    virtual QCString trEventDocumentation()
+    {
+      return "Documentacin de los Eventos";
+    }
+
+    /*! Used as a heading for a list of Java class types with package scope.
+     */
+    virtual QCString trPackageTypes()
+    { 
+      return "Tipos del Paquete";
+    }
+    
+    /*! Used as a heading for a list of Java class functions with package 
+     * scope. 
+     */
+    virtual QCString trPackageMembers()
+    { 
+      return "Funciones del Paquete";
+    }
+
+    /*! Used as a heading for a list of static Java class functions with 
+     *  package scope.
+     */
+    virtual QCString trStaticPackageMembers()
+    { 
+      return "Funciones Estticas del Paquete";
+    }
+
+    /*! Used as a heading for a list of Java class variables with package 
+     * scope.
+     */
+    virtual QCString trPackageAttribs()
+    { 
+      return "Atributos del Paquete";
+    }
+
+    /*! Used as a heading for a list of static Java class variables with 
+     * package scope.
+     */
+    virtual QCString trStaticPackageAttribs()
+    { 
+      return "Atributos Estticos del Paquete";
+    }
+     
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.1
+//////////////////////////////////////////////////////////////////////////
+
+    /*! Used in the quick index of a class/file/namespace member list page 
+     *  to link to the unfiltered list of all members.
+     */
+    virtual QCString trAll()
+    {
+      return "Todo";
+    }
+
+    /*! Put in front of the call graph for a function. */
+    virtual QCString trCallGraph()
+    {
+      return "Grfico de llamadas para esta funcin:";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.3
+//////////////////////////////////////////////////////////////////////////
+
+
+    /*! When the search engine is enabled this text is put in the index 
+     *  of each page before the search field. 
+     */
+    virtual QCString trSearchForIndex()
+    {
+      return "Buscar";
+    }
+
+    /*! This string is used as the title for the page listing the search
+     *  results.
+     */
+    virtual QCString trSearchResultsTitle()
+    {
+      return "Resultados de la Bsqueda";
+    }
+
+    /*! This string is put just before listing the search results. The
+     *  text can be different depending on the number of documents found.
+     *  Inside the text you can put the special marker $num to insert
+     *  the number representing the actual number of search results.
+     *  The @a numDocuments parameter can be either 0, 1 or 2, where the 
+     *  value 2 represents 2 or more matches. HTML markup is allowed inside
+     *  the returned string.
+     */
+    virtual QCString trSearchResults(int numDocuments)
+    {
+      if (numDocuments==0)
+      {
+        return "Disculpe, no se encontraron documentos que coincidan con su bsqueda.";
+      }
+      else if (numDocuments==1)
+      {
+        return "Se encontr <b>1</b> documento que coincide con su bsqueda.";
+      }
+      else 
+      {
+        return "Se encontraron <b>$num</b> documentos que coinciden con su bsqueda. "
+               "Se muestran los mejores resultados primero.";
+      }
+    }
+
+    /*! This string is put before the list of matched words, for each search 
+     *  result. What follows is the list of words that matched the query.
+     */
+    virtual QCString trSearchMatches()
+    {
+      return "Coincidencias:";
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.8
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used in HTML as the title of page with source code for file filename
+     */
+    virtual QCString trSourceFile(QCString& filename)
+    {
+      return "Fichero Fuente " + filename;
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.3.9
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This is used as the name of the chapter containing the directory
+     *  hierarchy.
+     */
+    virtual QCString trDirIndex()
+    { return "Jerarqua de Directorio"; }
+
+    /*! This is used as the name of the chapter containing the documentation
+     *  of the directories.
+     */
+    virtual QCString trDirDocumentation()
+    { return "Documentacin de Directorio"; }
+
+    /*! This is used as the title of the directory index and also in the
+     *  Quick links of an HTML page, to link to the directory hierarchy.
+     */
+    virtual QCString trDirectories()
+    { return "Directorios"; }
+
+    /*! This returns a sentences that introduces the directory hierarchy. 
+     *  and the fact that it is sorted alphabetically per level
+     */
+    virtual QCString trDirDescription()
+    { return "La jeraqua de este directorio est ordenada casi, "
+             "pero no completamente, de forma alfabtica:";
+    }
+
+    /*! This returns the title of a directory page. The name of the
+     *  directory is passed via \a dirName.
+     */
+    virtual QCString trDirReference(const char *dirName)
+    { QCString result="Referencia del Directorio "; result+=dirName; return result; }
+
+    /*! This returns the word directory with or without starting capital
+     *  (\a first_capital) and in sigular or plural form (\a singular).
+     */
+    virtual QCString trDir(bool first_capital, bool singular)
+    { 
+      QCString result((first_capital ? "Directori" : "directori"));
+      if (singular) result+="o"; else result+="os";
+      return result; 
+    }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.4.1
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This text is added to the documentation when the \\overload command
+     *  is used for a overloaded function.
+     */
+    virtual QCString trOverloadText()
+    {
+       return "Esta es una funcin miembro sobrecargada que se "
+              "suministra por conveniencia. Difiere de la anterior "
+              "funcin solamente en los argumentos que acepta.";
+    }
 };
 
 
