@@ -2,7 +2,7 @@
  *
  * 
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -29,7 +29,7 @@
 #ifndef TRANSLATOR_HU_H
 #define TRANSLATOR_HU_H
 
-class TranslatorHungarian : public TranslatorAdapter_1_4_1
+class TranslatorHungarian : public TranslatorAdapter_1_4_6
 {
   private:
     const char * zed(char c)
@@ -47,20 +47,20 @@ class TranslatorHungarian : public TranslatorAdapter_1_4_1
   public:
 
     // --- Language control methods -------------------
-    QCString idLanguage()
+    virtual QCString idLanguage()
     { return "hungarian"; }
     /*! Used to get the command(s) for the language support. This method
      *  was designed for languages which do not prefer babel package.
      *  If this methods returns empty string, then the latexBabelPackage()
      *  method is used to generate the command for using the babel package.
      */
-    QCString latexLanguageSupportCommand()
+    virtual QCString latexLanguageSupportCommand()
     {
-      return "";
+      return "\\usepackage{t1enc}\n\\usepackage[latin2]{inputenc}\n\\usepackage[magyar]{babel}\n";
     }
 
     /*! return the language charset. This will be used for the HTML output */
-    QCString idLanguageCharset()
+    virtual QCString idLanguageCharset()
     {
       return "iso-8859-2";
     }
@@ -68,31 +68,31 @@ class TranslatorHungarian : public TranslatorAdapter_1_4_1
     // --- Language translation methods -------------------
 
     /*! used in the compound documentation before a list of related functions. */
-    QCString trRelatedFunctions()
+    virtual QCString trRelatedFunctions()
     { return "Kapcsold fggvnyek"; }
 
     /*! subscript for the related functions. */
-    QCString trRelatedSubscript()
+    virtual QCString trRelatedSubscript()
     { return "(Figyelem! Ezek a fggvnyek nem tagjai az osztlynak!)"; }
 
     /*! header that is put before the detailed description of files, classes and namespaces. */
-    QCString trDetailedDescription()
+    virtual QCString trDetailedDescription()
     { return "Rszletes lers"; }
 
     /*! header that is put before the list of typedefs. */
-    QCString trMemberTypedefDocumentation()
+    virtual QCString trMemberTypedefDocumentation()
     { return "Tpusdefinci-tagok dokumentcija"; }
     
     /*! header that is put before the list of enumerations. */
-    QCString trMemberEnumerationDocumentation()
+    virtual QCString trMemberEnumerationDocumentation()
     { return "Enumerci-tagok dokumentcija"; }
     
     /*! header that is put before the list of member functions. */
-    QCString trMemberFunctionDocumentation()
+    virtual QCString trMemberFunctionDocumentation()
     { return "Tagfggvnyek dokumentcija"; }
     
     /*! header that is put before the list of member attributes. */
-    QCString trMemberDataDocumentation()
+    virtual QCString trMemberDataDocumentation()
     {
       if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
       {
@@ -105,26 +105,26 @@ class TranslatorHungarian : public TranslatorAdapter_1_4_1
     }
 
     /*! this is the text of a link put after brief descriptions. */
-    QCString trMore() 
+    virtual QCString trMore()
     { return "Rszletek..."; }
 
     /*! put in the class documentation */
-    QCString trListOfAllMembers()
+    virtual QCString trListOfAllMembers()
     { return "A tagok teljes listja."; }
 
     /*! used as the title of the "list of all members" page of a class */
-    QCString trMemberList()
+    virtual QCString trMemberList()
     { return "Taglista"; }
 
     /*! this is the first part of a sentence that is followed by a class name */
-    QCString trThisIsTheListOfAllMembers()
+    virtual QCString trThisIsTheListOfAllMembers()
     { return "A(z) "; }
 
     /*! this is the remainder of the sentence after the class name */
-    QCString trIncludingInheritedMembers()
+    virtual QCString trIncludingInheritedMembers()
     { return " osztly tagjainak teljes listja, az rklt tagokkal egytt."; }
     
-    QCString trGeneratedAutomatically(const char *s)
+    virtual QCString trGeneratedAutomatically(const char *s)
     { QCString result="Ezt a dokumentcit a Doxygen ksztette ";
       if (s) result+=(QCString)" a" + zed(s[0])+s+(QCString)" projekthez";
       result+=" a forrskdbl."; 
@@ -132,15 +132,15 @@ class TranslatorHungarian : public TranslatorAdapter_1_4_1
     }
 
     /*! put after an enum name in the list of all members */
-    QCString trEnumName()
+    virtual QCString trEnumName()
     { return "enum"; }
     
     /*! put after an enum value in the list of all members */
-    QCString trEnumValue()
+    virtual QCString trEnumValue()
     { return "enum-rtk"; }
     
     /*! put after an undocumented member in the list of all members */
-    QCString trDefinedIn()
+    virtual QCString trDefinedIn()
     { return "definilja:"; }
 
     // quick reference sections
@@ -148,15 +148,15 @@ class TranslatorHungarian : public TranslatorAdapter_1_4_1
     /*! This is put above each page as a link to the list of all groups of 
      *  compounds or files (see the \\group command).
      */
-    QCString trModules()
+    virtual QCString trModules()
     { return "Modulok"; }
     
     /*! This is put above each page as a link to the class hierarchy */
-    QCString trClassHierarchy()
+    virtual QCString trClassHierarchy()
     { return "Osztlyhierarchia"; }
     
     /*! This is put above each page as a link to the list of annotated classes */
-    QCString trCompoundList()
+    virtual QCString trCompoundList()
     { 
       if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
       {
@@ -169,15 +169,11 @@ class TranslatorHungarian : public TranslatorAdapter_1_4_1
     }
     
     /*! This is put above each page as a link to the list of documented files */
-    QCString trFileList()
+    virtual QCString trFileList()
     { return "Fjllista"; }
 
-    /*! This is put above each page as a link to the list of all verbatim headers */
-    QCString trHeaderFiles()
-    { return "Defincis fjlok"; }
-
     /*! This is put above each page as a link to all members of compounds. */
-    QCString trCompoundMembers()
+    virtual QCString trCompoundMembers()
     { 
       if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
       {
@@ -190,7 +186,7 @@ class TranslatorHungarian : public TranslatorAdapter_1_4_1
     }
 
     /*! This is put above each page as a link to all members of files. */
-    QCString trFileMembers()
+    virtual QCString trFileMembers()
     { 
       if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
       {
@@ -203,25 +199,25 @@ class TranslatorHungarian : public TranslatorAdapter_1_4_1
     }
 
     /*! This is put above each page as a link to all related pages. */
-    QCString trRelatedPages()
+    virtual QCString trRelatedPages()
     { return "Kapcsold lapok"; }
 
     /*! This is put above each page as a link to all examples. */
-    QCString trExamples()
+    virtual QCString trExamples()
     { return "Pldk"; }
 
     /*! This is put above each page as a link to the search engine. */
-    QCString trSearch()
+    virtual QCString trSearch()
     { return "Keress"; }
 
     /*! This is an introduction to the class hierarchy. */
-    QCString trClassHierarchyDescription()
+    virtual QCString trClassHierarchyDescription()
     { return "Majdnem (de nem teljesen) betrendbe szedett "
              "leszrmazsi lista:";
     }
 
     /*! This is an introduction to the list with all files. */
-    QCString trFileListDescription(bool extractAll)
+    virtual QCString trFileListDescription(bool extractAll)
     {
       QCString result="Az sszes ";
       if (!extractAll) result+="dokumentlt ";
@@ -230,7 +226,7 @@ class TranslatorHungarian : public TranslatorAdapter_1_4_1
     }
 
     /*! This is an introduction to the annotated compound list. */
-    QCString trCompoundListDescription()
+    virtual QCString trCompoundListDescription()
     { 
       
       if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
@@ -245,7 +241,7 @@ class TranslatorHungarian : public TranslatorAdapter_1_4_1
     }
 
     /*! This is an introduction to the page with all class members. */
-    QCString trCompoundMembersDescription(bool extractAll)
+    virtual QCString trCompoundMembersDescription(bool extractAll)
     {
       QCString result="Az sszes ";
       if (!extractAll)
@@ -287,7 +283,7 @@ class TranslatorHungarian : public TranslatorAdapter_1_4_1
     }
 
     /*! This is an introduction to the page with all file members. */
-    QCString trFileMembersDescription(bool extractAll)
+    virtual QCString trFileMembersDescription(bool extractAll)
     {
       QCString result="Az sszes ";
       if (!extractAll) result+="dokumentlt ";
@@ -308,51 +304,41 @@ class TranslatorHungarian : public TranslatorAdapter_1_4_1
       return result;
     }
 
-    /*! This is an introduction to the page with the list of all header files. */
-    QCString trHeaderFilesDescription()
-    { return "A Programozi Interfszt (API) alkot defincis fjlok listja:"; }
-
     /*! This is an introduction to the page with the list of all examples */
-    QCString trExamplesDescription()
+    virtual QCString trExamplesDescription()
     { return "A pldk listja:"; }
 
     /*! This is an introduction to the page with the list of related pages */
-    QCString trRelatedPagesDescription()
+    virtual QCString trRelatedPagesDescription()
     { return "A kapcsold dokumentcik listja:"; }
 
     /*! This is an introduction to the page with the list of class/file groups */
-    QCString trModulesDescription()
+    virtual QCString trModulesDescription()
     { return "A modulok listja:"; }
 
-    /*! This sentences is used in the annotated class/file lists if no brief
-     * description is given. 
-     */
-    QCString trNoDescriptionAvailable()
-    { return "Nincs lers"; }
-    
     // index titles (the project name is prepended for these) 
 
 
     /*! This is used in HTML as the title of index.html. */
-    QCString trDocumentation()
+    virtual QCString trDocumentation()
     { return "Dokumentci"; }
 
     /*! This is used in LaTeX as the title of the chapter with the 
      * index of all groups.
      */
-    QCString trModuleIndex()
+    virtual QCString trModuleIndex()
     { return "Modulmutat"; }
 
     /*! This is used in LaTeX as the title of the chapter with the 
      * class hierarchy.
      */
-    QCString trHierarchicalIndex()
+    virtual QCString trHierarchicalIndex()
     { return "Hierarchikus mutat"; }
 
     /*! This is used in LaTeX as the title of the chapter with the 
      * annotated compound index.
      */
-    QCString trCompoundIndex()
+    virtual QCString trCompoundIndex()
     {
       if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
       { 
@@ -367,131 +353,134 @@ class TranslatorHungarian : public TranslatorAdapter_1_4_1
     /*! This is used in LaTeX as the title of the chapter with the
      * list of all files.
      */
-    QCString trFileIndex() 
+    virtual QCString trFileIndex()
     { return "Fjlmutat"; }
 
     /*! This is used in LaTeX as the title of the chapter containing
      *  the documentation of all groups.
      */
-    QCString trModuleDocumentation()
+    virtual QCString trModuleDocumentation()
     { return "Modulok dokumentcija"; }
 
     /*! This is used in LaTeX as the title of the chapter containing
      *  the documentation of all classes, structs and unions.
      */
-    QCString trClassDocumentation()
-    { return "Osztlyok dokumentcija"; }
+    virtual QCString trClassDocumentation()
+    {
+      if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
+      {
+        return "Adatszerkezetek dokumentcija";
+      }
+      else
+      {
+        return "Osztlyok dokumentcija";
+      }
+    }
 
     /*! This is used in LaTeX as the title of the chapter containing
      *  the documentation of all files.
      */
-    QCString trFileDocumentation()
+    virtual QCString trFileDocumentation()
     { return "Fjlok dokumentcija"; }
 
     /*! This is used in LaTeX as the title of the chapter containing
      *  the documentation of all examples.
      */
-    QCString trExampleDocumentation()
+    virtual QCString trExampleDocumentation()
     { return "Pldk dokumentcija"; }
 
     /*! This is used in LaTeX as the title of the chapter containing
      *  the documentation of all related pages.
      */
-    QCString trPageDocumentation()
+    virtual QCString trPageDocumentation()
     { return "Kapcsold dokumentcik"; }
 
     /*! This is used in LaTeX as the title of the document */
-    QCString trReferenceManual()
+    virtual QCString trReferenceManual()
     { return "Referencia kziknyv"; }
     
     /*! This is used in the documentation of a file as a header before the 
      *  list of defines
      */
-    QCString trDefines()
+    virtual QCString trDefines()
     { return "Makrdefincik"; }
 
     /*! This is used in the documentation of a file as a header before the 
      *  list of function prototypes
      */
-    QCString trFuncProtos()
+    virtual QCString trFuncProtos()
     { return "Fggvny-prototpusok"; }
 
     /*! This is used in the documentation of a file as a header before the 
      *  list of typedefs
      */
-    QCString trTypedefs()
+    virtual QCString trTypedefs()
     { return "Tpusdefincik"; }
 
     /*! This is used in the documentation of a file as a header before the 
      *  list of enumerations
      */
-    QCString trEnumerations()
+    virtual QCString trEnumerations()
     { return "Enumercik"; }
 
     /*! This is used in the documentation of a file as a header before the 
      *  list of (global) functions
      */
-    QCString trFunctions()
+    virtual QCString trFunctions()
     { return "Fggvnyek"; }
 
     /*! This is used in the documentation of a file as a header before the 
      *  list of (global) variables
      */
-    QCString trVariables()
+    virtual QCString trVariables()
     { return "Vltozk"; }
 
     /*! This is used in the documentation of a file as a header before the 
      *  list of (global) variables
      */
-    QCString trEnumerationValues()
+    virtual QCString trEnumerationValues()
     { return "Enumerci-rtkek"; }
     
     /*! This is used in the documentation of a file before the list of
      *  documentation blocks for defines
      */
-    QCString trDefineDocumentation()
+    virtual QCString trDefineDocumentation()
     { return "Makrdefincik dokumentcija"; }
 
     /*! This is used in the documentation of a file/namespace before the list 
      *  of documentation blocks for function prototypes
      */
-    QCString trFunctionPrototypeDocumentation()
+    virtual QCString trFunctionPrototypeDocumentation()
     { return "Fggvny-prototpusok dokumentcija"; }
 
     /*! This is used in the documentation of a file/namespace before the list 
      *  of documentation blocks for typedefs
      */
-    QCString trTypedefDocumentation()
+    virtual QCString trTypedefDocumentation()
     { return "Tpusdefincik dokumentcija"; }
 
     /*! This is used in the documentation of a file/namespace before the list 
      *  of documentation blocks for enumeration types
      */
-    QCString trEnumerationTypeDocumentation()
+    virtual QCString trEnumerationTypeDocumentation()
     { return "Enumercik dokumentcija"; }
 
-    /*! This is used in the documentation of a file/namespace before the list 
-     *  of documentation blocks for enumeration values
-     */
-    QCString trEnumerationValueDocumentation()
-    { return "Enumerci-rtkek dokumentcija"; }
-
     /*! This is used in the documentation of a file/namespace before the list 
      *  of documentation blocks for functions
      */
-    QCString trFunctionDocumentation()
+    virtual QCString trFunctionDocumentation()
     { return "Fggvnyek dokumentcija"; }
 
     /*! This is used in the documentation of a file/namespace before the list 
      *  of documentation blocks for variables
      */
-    QCString trVariableDocumentation()
+    virtual QCString trVariableDocumentation()
     { return "Vltozk dokumentcija"; }
 
     /*! This is used in the documentation of a file/namespace/group before 
      *  the list of links to documented compounds
      */
-    QCString trCompounds()
+    virtual QCString trCompounds()
     { 
       if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
       {
@@ -506,7 +495,7 @@ class TranslatorHungarian : public TranslatorAdapter_1_4_1
     /*! This is used in the standard footer of each page and indicates when 
      *  the page was generated 
      */
-    QCString trGeneratedAt(const char *date,const char *projName)
+    virtual QCString trGeneratedAt(const char *date,const char *projName)
     { 
       QCString result=(QCString)"";
       if (projName) result+=(QCString)"Projekt: "+projName;
@@ -515,59 +504,51 @@ class TranslatorHungarian : public TranslatorAdapter_1_4_1
     }
     /*! This is part of the sentence used in the standard footer of each page.
      */
-    QCString trWrittenBy()
+    virtual QCString trWrittenBy()
     {
       return " melyet rt ";
     }
 
     /*! this text is put before a class diagram */
-    QCString trClassDiagram(const char *clName)
+    virtual QCString trClassDiagram(const char *clName)
     {
       return (QCString)"A"+zed(clName[0])+clName+" osztly szrmazsi diagramja:";
     }
     
     /*! this text is generated when the \\internal command is used. */
-    QCString trForInternalUseOnly()
+    virtual QCString trForInternalUseOnly()
     { return "CSAK BELS HASZNLATRA!"; }
 
-    /*! this text is generated when the \\reimp command is used. */
-    QCString trReimplementedForInternalReasons()
-    { return "Bels okok miatt jraimplementlva; az API-t nem rinti."; }
-
     /*! this text is generated when the \\warning command is used. */
-    QCString trWarning()
+    virtual QCString trWarning()
     { return "Figyelmeztets"; }
 
-    /*! this text is generated when the \\bug command is used. */
-    QCString trBugsAndLimitations()
-    { return "Hibk s korltozsok"; }
-
     /*! this text is generated when the \\version command is used. */
-    QCString trVersion()
+    virtual QCString trVersion()
     { return "Verzi"; }
 
     /*! this text is generated when the \\date command is used. */
-    QCString trDate()
+    virtual QCString trDate()
     { return "Dtum"; }
 
     /*! this text is generated when the \\return command is used. */
-    QCString trReturns()
+    virtual QCString trReturns()
     { return "Visszatrsi rtk"; }
 
     /*! this text is generated when the \\sa command is used. */
-    QCString trSeeAlso()
+    virtual QCString trSeeAlso()
     { return "Lsd mg"; }
 
     /*! this text is generated when the \\param command is used. */
-    QCString trParameters()
+    virtual QCString trParameters()
     { return "Paramterek"; }
 
     /*! this text is generated when the \\exception command is used. */
-    QCString trExceptions()
+    virtual QCString trExceptions()
     { return "Kivtelek"; }
     
     /*! this text is used in the title page of a LaTeX document. */
-    QCString trGeneratedBy()
+    virtual QCString trGeneratedBy()
     { return "Ksztette"; }
 
 //////////////////////////////////////////////////////////////////////////
@@ -575,11 +556,11 @@ class TranslatorHungarian : public TranslatorAdapter_1_4_1
 //////////////////////////////////////////////////////////////////////////
     
     /*! used as the title of page containing all the index of all namespaces. */
-    QCString trNamespaceList()
+    virtual QCString trNamespaceList()
     { return "Nvtrlista"; }
 
     /*! used as an introduction to the namespace list */
-    QCString trNamespaceListDescription(bool extractAll)
+    virtual QCString trNamespaceListDescription(bool extractAll)
     {
       QCString result="Az sszes ";
       if (!extractAll) result+="dokumentlt ";
@@ -590,7 +571,7 @@ class TranslatorHungarian : public TranslatorAdapter_1_4_1
     /*! used in the class documentation as a header before the list of all
      *  friends of a class
      */
-    QCString trFriends()
+    virtual QCString trFriends()
     { return "Bartok"; }
     
 //////////////////////////////////////////////////////////////////////////
@@ -600,7 +581,7 @@ class TranslatorHungarian : public TranslatorAdapter_1_4_1
     /*! used in the class documentation as a header before the list of all
      * related classes 
      */
-    QCString trRelatedFunctionDocumentation()
+    virtual QCString trRelatedFunctionDocumentation()
     { return "Bart s kapcsold fggvnyek dokumentcija"; }
     
 //////////////////////////////////////////////////////////////////////////
@@ -608,7 +589,7 @@ class TranslatorHungarian : public TranslatorAdapter_1_4_1
 //////////////////////////////////////////////////////////////////////////
 
     /*! used as the title of the HTML page of a class/struct/union */
-    QCString trCompoundReference(const char *clName,
+    virtual QCString trCompoundReference(const char *clName,
                                     ClassDef::CompoundType compType,
                                     bool isTemplate)
     {
@@ -629,7 +610,7 @@ class TranslatorHungarian : public TranslatorAdapter_1_4_1
     }
 
     /*! used as the title of the HTML page of a file */
-    QCString trFileReference(const char *fileName)
+    virtual QCString trFileReference(const char *fileName)
     {
       QCString result=fileName;
       result+=" fjlreferencia"; 
@@ -637,38 +618,38 @@ class TranslatorHungarian : public TranslatorAdapter_1_4_1
     }
 
     /*! used as the title of the HTML page of a namespace */
-    QCString trNamespaceReference(const char *namespaceName)
+    virtual QCString trNamespaceReference(const char *namespaceName)
     {
       QCString result=namespaceName;
       result+=" nvtr-referencia";
       return result;
     }
     
-    QCString trPublicMembers()
+    virtual QCString trPublicMembers()
     { return "Publikus tagfggvnyek"; }
-    QCString trPublicSlots()
+    virtual QCString trPublicSlots()
     { return "Publikus rsek"; }
-    QCString trSignals()
+    virtual QCString trSignals()
     { return "Szignlok"; }
-    QCString trStaticPublicMembers()
+    virtual QCString trStaticPublicMembers()
     { return "Statikus publikus tagfggvnyek"; }
-    QCString trProtectedMembers()
+    virtual QCString trProtectedMembers()
     { return "Vdett tagfggvnyek"; }
-    QCString trProtectedSlots()
+    virtual QCString trProtectedSlots()
     { return "Vdett rsek"; }
-    QCString trStaticProtectedMembers()
+    virtual QCString trStaticProtectedMembers()
     { return "Statikus vdett tagfggvnyek"; }
-    QCString trPrivateMembers()
+    virtual QCString trPrivateMembers()
     { return "Privt tagfggvnyek"; }
-    QCString trPrivateSlots()
+    virtual QCString trPrivateSlots()
     { return "Privt rsek"; }
-    QCString trStaticPrivateMembers()
+    virtual QCString trStaticPrivateMembers()
     { return "Statikus privt tagfggvnyek"; }
     
     /*! this function is used to produce a comma-separated list of items.
      *  use generateMarker(i) to indicate where item i should be put.
      */
-    QCString trWriteList(int numEntries)
+    virtual QCString trWriteList(int numEntries)
     {
       QCString result;
       int i;
@@ -693,7 +674,7 @@ class TranslatorHungarian : public TranslatorAdapter_1_4_1
     /*! used in class documentation to produce a list of base classes,
      *  if class diagrams are disabled.
      */
-    QCString trInheritsList(int numEntries)
+    virtual QCString trInheritsList(int numEntries)
     {
       return "sk: "+trWriteList(numEntries)+".";
     }
@@ -701,7 +682,7 @@ class TranslatorHungarian : public TranslatorAdapter_1_4_1
     /*! used in class documentation to produce a list of super classes,
      *  if class diagrams are disabled.
      */
-    QCString trInheritedByList(int numEntries)
+    virtual QCString trInheritedByList(int numEntries)
     {
       return "Leszrmazottak: "+trWriteList(numEntries)+".";
     }
@@ -709,7 +690,7 @@ class TranslatorHungarian : public TranslatorAdapter_1_4_1
     /*! used in member documentation blocks to produce a list of 
      *  members that are hidden by this one.
      */
-    QCString trReimplementedFromList(int numEntries)
+    virtual QCString trReimplementedFromList(int numEntries)
     {
       return "jraimplementlt sk: "+trWriteList(numEntries)+".";
     }
@@ -717,17 +698,17 @@ class TranslatorHungarian : public TranslatorAdapter_1_4_1
     /*! used in member documentation blocks to produce a list of
      *  all member that overwrite the implementation of this member.
      */
-    QCString trReimplementedInList(int numEntries)
+    virtual QCString trReimplementedInList(int numEntries)
     {
       return "jraimplementl leszrmazottak: "+trWriteList(numEntries)+".";
     }
 
     /*! This is put above each page as a link to all members of namespaces. */
-    QCString trNamespaceMembers()
+    virtual QCString trNamespaceMembers()
     { return "Nvtrtagok"; }
 
     /*! This is an introduction to the page with all namespace members */
-    QCString trNamespaceMemberDescription(bool extractAll)
+    virtual QCString trNamespaceMemberDescription(bool extractAll)
     { 
       QCString result="Az sszes ";
       if (!extractAll) result+="dokumentlt ";
@@ -741,13 +722,13 @@ class TranslatorHungarian : public TranslatorAdapter_1_4_1
     /*! This is used in LaTeX as the title of the chapter with the 
      *  index of all namespaces.
      */
-    QCString trNamespaceIndex()
+    virtual QCString trNamespaceIndex()
     { return "Nvtrmutat"; }
 
     /*! This is used in LaTeX as the title of the chapter containing
      *  the documentation of all namespaces.
      */
-    QCString trNamespaceDocumentation()
+    virtual QCString trNamespaceDocumentation()
     { return "Nvterek dokumentcija"; }
 
 //////////////////////////////////////////////////////////////////////////
@@ -757,7 +738,7 @@ class TranslatorHungarian : public TranslatorAdapter_1_4_1
     /*! This is used in the documentation before the list of all
      *  namespaces in a file.
      */
-    QCString trNamespaces()
+    virtual QCString trNamespaces()
     { return "Nvterek"; }
 
 //////////////////////////////////////////////////////////////////////////
@@ -767,7 +748,7 @@ class TranslatorHungarian : public TranslatorAdapter_1_4_1
     /*! This is put at the bottom of a class documentation page and is
      *  followed by a list of files that were used to generate the page.
      */
-    QCString trGeneratedFromFiles(ClassDef::CompoundType compType,
+    virtual QCString trGeneratedFromFiles(ClassDef::CompoundType compType,
         bool single)
     { // here s is one of " Class", " Struct" or " Union"
       // single is true implies a single file
@@ -791,7 +772,7 @@ class TranslatorHungarian : public TranslatorAdapter_1_4_1
     /*! This is in the (quick) index as a link to the alphabetical compound
      * list.
      */
-    QCString trAlphabeticalList()
+    virtual QCString trAlphabeticalList()
     { return "Betrendes lista"; }
 
 //////////////////////////////////////////////////////////////////////////
@@ -799,33 +780,29 @@ class TranslatorHungarian : public TranslatorAdapter_1_4_1
 //////////////////////////////////////////////////////////////////////////
 
     /*! This is used as the heading text for the retval command. */
-    QCString trReturnValues()
+    virtual QCString trReturnValues()
     { return "Visszatrsi rtkek"; }
 
     /*! This is in the (quick) index as a link to the main page (index.html)
      */
-    QCString trMainPage()
+    virtual QCString trMainPage()
     { return "Foldal"; }
 
     /*! This is used in references to page that are put in the LaTeX 
      *  documentation. It should be an abbreviation of the word page.
      */
-    QCString trPageAbbreviation()
+    virtual QCString trPageAbbreviation()
     { return "o."; }
 
 //////////////////////////////////////////////////////////////////////////
 // new since 0.49-991003
 //////////////////////////////////////////////////////////////////////////
 
-    QCString trSources()
-    {
-      return "Forrsok";
-    }
-    QCString trDefinedAtLineInSourceFile()
+    virtual QCString trDefinedAtLineInSourceFile()
     {
       return "Definci a(z) @1 fjl @0. sorban.";
     }
-    QCString trDefinedInSourceFile()
+    virtual QCString trDefinedInSourceFile()
     {
       return "Definci a(z) @0 fjlban.";
     }
@@ -834,7 +811,7 @@ class TranslatorHungarian : public TranslatorAdapter_1_4_1
 // new since 0.49-991205
 //////////////////////////////////////////////////////////////////////////
 
-    QCString trDeprecated()
+    virtual QCString trDeprecated()
     {
       return "Ellenjavallt";
     }
@@ -844,68 +821,68 @@ class TranslatorHungarian : public TranslatorAdapter_1_4_1
 //////////////////////////////////////////////////////////////////////////
 
     /*! this text is put before a collaboration diagram */
-    QCString trCollaborationDiagram(const char *clName)
+    virtual QCString trCollaborationDiagram(const char *clName)
     {
       return (QCString)"A"+zed(clName[0])+clName+" osztly egyttmkdsi diagramja:";
     }
     /*! this text is put before an include dependency graph */
-    QCString trInclDepGraph(const char *fName)
+    virtual QCString trInclDepGraph(const char *fName)
     {
       return (QCString)"A"+zed(fName[0])+fName+" defincis fjl fggsi grfja:";
     }
     /*! header that is put before the list of constructor/destructors. */
-    QCString trConstructorDocumentation()
+    virtual QCString trConstructorDocumentation()
     {
       return "Konstruktorok s destruktorok dokumentcija"; 
     }
     /*! Used in the file documentation to point to the corresponding sources. */
-    QCString trGotoSourceCode()
+    virtual QCString trGotoSourceCode()
     {
       return "Ugrs a fjl forrskdjhoz.";
     }
     /*! Used in the file sources to point to the corresponding documentation. */
-    QCString trGotoDocumentation()
+    virtual QCString trGotoDocumentation()
     {
       return "Ugrs a fjl dokumentcijhoz.";
     }
     /*! Text for the \\pre command */
-    QCString trPrecondition()
+    virtual QCString trPrecondition()
     {
       return "Elfelttel";
     }
     /*! Text for the \\post command */
-    QCString trPostcondition()
+    virtual QCString trPostcondition()
     {
       return "Utfelttel";
     }
     /*! Text for the \\invariant command */
-    QCString trInvariant()
+    virtual QCString trInvariant()
     {
       return "Invarins";
     }
     /*! Text shown before a multi-line variable/enum initialization */
-    QCString trInitialValue()
+    virtual QCString trInitialValue()
     {
       return "Kezd rtk:";
     }
     /*! Text used the source code in the file index */
-    QCString trCode()
+    virtual QCString trCode()
     {
       return "forrskd";
     }
-    QCString trGraphicalHierarchy()
+    virtual QCString trGraphicalHierarchy()
     {
       return "Osztlyhierarchia-bra";
     }
-    QCString trGotoGraphicalHierarchy()
+    virtual QCString trGotoGraphicalHierarchy()
     {
       return "Ugrs az osztlyhierarchia-brhoz";
     }
-    QCString trGotoTextualHierarchy()
+    virtual QCString trGotoTextualHierarchy()
     {
       return "Ugrs az szveges osztlyhierarchihoz";
     }
-    QCString trPageIndex()
+    virtual QCString trPageIndex()
     {
       return "Oldalmutat";
     }
@@ -914,15 +891,15 @@ class TranslatorHungarian : public TranslatorAdapter_1_4_1
 // new since 1.1.0
 //////////////////////////////////////////////////////////////////////////
     
-    QCString trNote()
+    virtual QCString trNote()
     {
       return "Megjegyzs";
     }
-    QCString trPublicTypes()
+    virtual QCString trPublicTypes()
     {
       return "Publikus tpusok";
     }
-    QCString trPublicAttribs()
+    virtual QCString trPublicAttribs()
     {
       if (Config_getBool("OPTIMIZE_OUTPUT_FOR_C"))
       {
@@ -933,31 +910,31 @@ class TranslatorHungarian : public TranslatorAdapter_1_4_1
         return "Publikus attribtumok";
       }
     }
-    QCString trStaticPublicAttribs()
+    virtual QCString trStaticPublicAttribs()
     {
       return "Statikus publikus attribtumok";
     }
-    QCString trProtectedTypes()
+    virtual QCString trProtectedTypes()
     {
       return "Vdett tpusok";
     }
-    QCString trProtectedAttribs()
+    virtual QCString trProtectedAttribs()
     {
       return "Vdett attribtumok";
     }
-    QCString trStaticProtectedAttribs()
+    virtual QCString trStaticProtectedAttribs()
     {
       return "Statikus vdett attribtumok";
     }
-    QCString trPrivateTypes()
+    virtual QCString trPrivateTypes()
     {
       return "Privt tpusok";
     }
-    QCString trPrivateAttribs()
+    virtual QCString trPrivateAttribs()
     {
       return "Privt attribtumok";
     }
-    QCString trStaticPrivateAttribs()
+    virtual QCString trStaticPrivateAttribs()
     {
       return "Statikus privt attribtumok";
     }
@@ -967,12 +944,12 @@ class TranslatorHungarian : public TranslatorAdapter_1_4_1
 //////////////////////////////////////////////////////////////////////////
 
     /*! Used as a marker that is put before a todo item */
-    QCString trTodo()
+    virtual QCString trTodo()
     {
       return "Tennival";
     }
     /*! Used as the header of the todo list */
-    QCString trTodoList()
+    virtual QCString trTodoList()
     {
       return "Tennivalk listja";
     }
@@ -981,24 +958,24 @@ class TranslatorHungarian : public TranslatorAdapter_1_4_1
 // new since 1.1.4
 //////////////////////////////////////////////////////////////////////////
 
-    QCString trReferencedBy()
+    virtual QCString trReferencedBy()
     {
       return "Hivatkozsok:";
     }
-    QCString trRemarks()
+    virtual QCString trRemarks()
     {
       return "Megjegyzsek";
     }
-    QCString trAttention()
+    virtual QCString trAttention()
     {
       return "Figyelem";
     }
-    QCString trInclByDepGraph()
+    virtual QCString trInclByDepGraph()
     {
       return "Ez az bra azt mutatja, hogy mely fjlok gyazzk be "
              "kzvetve vagy kzvetlenl ezt a fjlt:";
     }
-    QCString trSince()
+    virtual QCString trSince()
     {
       return "Elszr bevezetve";
     }
@@ -1008,12 +985,12 @@ class TranslatorHungarian : public TranslatorAdapter_1_4_1
 //////////////////////////////////////////////////////////////////////////
 
     /*! title of the graph legend page */
-    QCString trLegendTitle()
+    virtual QCString trLegendTitle()
     {
       return "Jelmagyarzat";
     }
     /*! page explaining how the dot graph's should be interpreted */
-    QCString trLegendDocs()
+    virtual QCString trLegendDocs()
     {
       return 
         "Ez az oldal elmagyarzza hogyan kell rtelmezni a "
@@ -1074,7 +1051,7 @@ class TranslatorHungarian : public TranslatorAdapter_1_4_1
 
     }
     /*! text for the link to the legend page */
-    QCString trLegend()
+    virtual QCString trLegend()
     {
       return "Jelmagyarzat";
     }
@@ -1084,12 +1061,12 @@ class TranslatorHungarian : public TranslatorAdapter_1_4_1
 //////////////////////////////////////////////////////////////////////////
     
     /*! Used as a marker that is put before a test item */
-    QCString trTest()
+    virtual QCString trTest()
     {
       return "Teszt";
     }
     /*! Used as the header of the test list */
-    QCString trTestList()
+    virtual QCString trTestList()
     {
       return "Tesztlista";
     }
@@ -1123,11 +1100,6 @@ class TranslatorHungarian : public TranslatorAdapter_1_4_1
 // new since 1.2.4
 //////////////////////////////////////////////////////////////////////////
 
-    /*! Used for Java interfaces in the summary section of Java packages */
-    virtual QCString trInterfaces()
-    {
-      return "Interfszek";
-    }
     /*! Used for Java classes in the summary section of Java packages */
     virtual QCString trClasses()
     {
@@ -1160,11 +1132,6 @@ class TranslatorHungarian : public TranslatorAdapter_1_4_1
     {
       return "Csomagok";
     }
-    /*! Used as a chapter title for Latex & RTF output */
-    virtual QCString trPackageDocumentation()
-    {
-      return "Csomagok dokumentcija";
-    }
     /*! Text shown before a multi-line define */
     virtual QCString trDefineValue()
     {
@@ -1301,17 +1268,6 @@ class TranslatorHungarian : public TranslatorAdapter_1_4_1
       return result; 
     }
    
-    /*! This is used for translation of the word that will possibly
-     *  be followed by a single name or by a list of names 
-     *  of the category.
-     */
-    virtual QCString trField(bool first_capital, bool /*singular*/)
-    { 
-      QCString result((first_capital ? "Mez" : "mez"));
-      //if (!singular)  result+="s";
-      return result; 
-    }
-
     /*! This is used for translation of the word that will possibly
      *  be followed by a single name or by a list of names 
      *  of the category.
@@ -1572,6 +1528,18 @@ class TranslatorHungarian : public TranslatorAdapter_1_4_1
       return result; 
     }
 
+//////////////////////////////////////////////////////////////////////////
+// new since 1.4.1
+//////////////////////////////////////////////////////////////////////////
+
+    /*! This text is added to the documentation when the \\overload command
+     *  is used for a overloaded function.
+     */
+    virtual QCString trOverloadText()
+    {
+       return "Ez egy tlterhelt tagfggvny."
+              "A fenti fggvnytl csak argumentumaiban klnbzik.";
+    }
 };
 
 #endif
