@@ -1,8 +1,8 @@
 /******************************************************************************
  *
- * 
+ * $Id: translator_nl.h,v 1.22 2001/03/19 19:27:42 root Exp $
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -1213,6 +1213,16 @@ class TranslatorDutch : public Translator
              "gebruik te vergemakkelijken. Ze verschilt alleen van de "
              "bovenstaande functie wat betreft de parameterlijst.";
     }
+
+//////////////////////////////////////////////////////////////////////////
+// new since 1.4.6
+//////////////////////////////////////////////////////////////////////////
+
+    /*! Put in front of the call graph for a function. */
+    virtual QCString trCallerGraph()
+    {
+      return "Hier is de caller graaf voor deze functie:";
+    }
     
 };
 
