@@ -3,7 +3,7 @@
  * $Id: xml.cpp,v 1.2 2001/01/01 10:15:18 root Exp $
  *
  *
- * Copyright (C) 1997-2005 by Dimitri van Heesch.
+ * Copyright (C) 1997-2006 by Dimitri van Heesch.
  *
  * Permission to use, copy, modify, and distribute this software and its
  * documentation under the terms of the GNU General Public License is hereby 
@@ -613,7 +613,7 @@ static void generateXMLForMember(MemberDef *md,QTextStream &ti,QTextStream &t,De
     if (md->isReadable()) t << "yes"; else t << "no";
     t << "\"";
 
-    t << "\" writable=\"";
+    t << " writable=\"";
     if (md->isWritable()) t << "yes"; else t << "no";
     t << "\"";
   }
@@ -953,7 +953,15 @@ static void writeInnerClasses(const ClassSDict *cl,QTextStream &t)
       if (cd->name().find('@')==-1) // skip anonymous scopes
       {
         t << "    <innerclass refid=\"" << cd->getOutputFileBase()
-          << "\">" << convertToXML(cd->name()) << "</innerclass>" << endl;
+          << "\" prot=\"";
+        switch(cd->protection())
+        {
+           case Public:    t << "public";     break;
+           case Protected: t << "protected";  break;
+           case Private:   t << "private";    break;
+           case Package:   t << "package";    break;
+        }
+        t << "\">" << convertToXML(cd->name()) << "</innerclass>" << endl;
       }
     }
   }
